@@ -2,7 +2,7 @@
 
 # flake8: noqa
 
-from .git import add, checkout, clone, commit, pull, push
+from .git import add, checkout, clone, commit, pull, push, is_git_repo
 from .options import (
     AddOptions,
     CheckoutOptions,
@@ -14,4 +14,4 @@ from .options import (
 from .repository import Repository
 from .workspace import Workspace
 
-__version__ = "0.7.0"
+__version__ = "0.8.0"
